@@ -37,7 +37,9 @@ test_that("returns first argument", {
   expect_equal(expect_output(1, NA), 1)
 })
 
-test_that("Unicode characters in output", {
+test_that("uses unicode characters in output where available", {
+  skip_if_not(l10n_info()$`UTF-8`)
+
   bar <- "\u2551"
   expect_success(expect_output(cat(bar), "\u2551"))
 })
